==> haskell-network-ip-0.3.0.2-106-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-EwJWLr80x3pDhM2V0g16yJ
key: network-ip-0.3.0.2-EwJWLr80x3pDhM2V0g16yJ
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: f4a534d83ad8119b2af1e1d422b492f8
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-EwJWLr80x3pDhM2V0g16yJ
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    data-dword-0.3.1.2-GKAtlXVogBl1ZIyGyAok8F
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    data-serializer-0.3.4-4ehRispsk8sKQqTA9havkS
    data-textual-0.3.0.2-JcBN6fuSb1V6idfyjVgOuM
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    parsers-0.12.10-FPg5oiObu8yFZNrwSw8L5c
    text-printer-0.5.0.1-BG33voC2AwgIsQ8qW3GjJY
    type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.3
id: network-ip-0.3.0.3-AOhbwUje1GyHWkemw2ehmL
key: network-ip-0.3.0.3-AOhbwUje1GyHWkemw2ehmL
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: f6f109347950ca8b8989b93bed7b7f17
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-ip-0.3.0.3
hs-libraries: HSnetwork-ip-0.3.0.3-AOhbwUje1GyHWkemw2ehmL
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    data-dword-0.3.1.3-69EZzPW33NHE8zFdipVI2F
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    data-serializer-0.3.4-4ehRispsk8sKQqTA9havkS
    data-textual-0.3.0.2-JcBN6fuSb1V6idfyjVgOuM
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    parsers-0.12.10-FPg5oiObu8yFZNrwSw8L5c
    text-printer-0.5.0.1-BG33voC2AwgIsQ8qW3GjJY
    type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
